@@ -62,19 +62,28 @@ pub trait FsBackend: Send + Sync {
 	const EXTENSION: &'static str;
 
 	/// Turn a [`Read`]er into an [`Entry`].
+	///
+	/// # Errors
+	///
+	/// Implementors should return a [`FsError::Serde`] error upon failure.
 	fn from_reader<R, T>(rdr: R) -> Result<T, FsError>
 	where
 		R: Read,
 		T: Entry;
 
 	/// Turn a [`Entry`] into a writable [`Vec`].
+	///
+	/// # Errors
+	///
+	/// Implementors should return a [`FsError::Serde`] error upon failure.
 	fn to_bytes<T>(value: &T) -> Result<Vec<u8>, FsError>
 	where
 		T: Entry;
 
 	/// Turns a key into a valid filename, with the extension.
+	#[must_use]
 	fn filename(id: &str) -> String {
-		id.to_string() + "." + Self::EXTENSION
+		id.to_owned() + "." + Self::EXTENSION
 	}
 
 	/// Resolves the path of a file.
@@ -89,6 +98,10 @@ pub trait FsBackend: Send + Sync {
 	}
 
 	/// Turns a filename into a valid key.
+	///
+	/// # Errors
+	///
+	/// Returns a [`FsError::InvalidFile`] when the file path does not have the correct extension.
 	fn resolve_key<P: AsRef<Path>>(&self, p: P) -> Result<String, FsError> {
 		let path = p.as_ref().to_path_buf();
 
@@ -111,6 +124,7 @@ pub trait FsBackend: Send + Sync {
 	fn base_directory(&self) -> PathBuf;
 }
 
+#[cfg_attr(docsrs, doc(cfg(feature = "fs")))]
 impl<RW: FsBackend> Backend for RW {
 	type Error = FsError;
 
@@ -275,3 +289,57 @@ impl<RW: FsBackend> Backend for RW {
 		})
 	}
 }
+
+#[cfg(all(test, feature = "fs"))]
+mod tests {
+	use std::{io, path::PathBuf};
+
+	use super::{FsBackend, FsError};
+	use crate::Entry;
+
+	#[derive(Debug, Default, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
+	struct MockFsBackend;
+
+	#[cfg(not(tarpaulin_include))]
+	impl FsBackend for MockFsBackend {
+		const EXTENSION: &'static str = "test";
+
+		fn from_reader<R, T>(_: R) -> Result<T, FsError>
+		where
+			R: io::Read,
+			T: Entry,
+		{
+			Err(FsError::Serde)
+		}
+
+		fn to_bytes<T>(_: &T) -> Result<Vec<u8>, FsError>
+		where
+			T: Entry,
+		{
+			Err(FsError::Serde)
+		}
+
+		fn base_directory(&self) -> PathBuf {
+			PathBuf::new()
+				.join(".")
+				.join("target")
+				.join("tests")
+				.join("fs")
+		}
+	}
+
+	#[test]
+	fn resolve_key() -> Result<(), FsError> {
+		let backend = MockFsBackend;
+
+		let key = "foo.test";
+
+		assert_eq!(backend.resolve_key(key)?, "foo");
+
+		let invalid = "bar.json";
+
+		assert!(backend.resolve_key(invalid).is_err());
+
+		Ok(())
+	}
+}
