@@ -7,32 +7,24 @@ use std::{
 use super::fs::{FsBackend, FsError};
 use crate::Entry;
 
-/// A type alias for an [`FsError`].
-#[deprecated(
-	since = "0.7.0",
-	note = "the JsonError alias will be removed, consider using the `FsError` instead."
-)]
-#[cfg_attr(docsrs, doc(cfg(feature = "json")))]
-pub type JsonError = FsError;
-
 /// A JSON based backend.
 #[derive(Debug, Default, Clone)]
 #[cfg_attr(docsrs, doc(cfg(feature = "json")))]
-pub struct JsonBackend {
-	base_directory: PathBuf,
-}
+pub struct JsonBackend(PathBuf);
 
 impl JsonBackend {
 	/// Create a new [`JsonBackend`].
-	pub fn new<P: AsRef<Path>>(path: P) -> Result<Self, JsonError> {
+	///
+	/// # Errors
+	///
+	/// Returns a [`FsError::PathNotDirectory`] if the given path is not a directory.
+	pub fn new<P: AsRef<Path>>(path: P) -> Result<Self, FsError> {
 		let path = path.as_ref().to_path_buf();
 
 		if path.is_file() {
 			Err(FsError::PathNotDirectory(path))
 		} else {
-			Ok(Self {
-				base_directory: path,
-			})
+			Ok(Self(path))
 		}
 	}
 }
@@ -56,72 +48,32 @@ impl FsBackend for JsonBackend {
 	}
 
 	fn base_directory(&self) -> PathBuf {
-		self.base_directory.clone()
+		self.0.clone()
 	}
 }
 
 #[cfg(all(test, feature = "json"))]
 mod tests {
-	use std::{
-		ffi::OsStr,
-		fmt::Debug,
-		fs,
-		io::Result as IoResult,
-		path::{Path, PathBuf},
-	};
+	use std::{fmt::Debug, fs, path::PathBuf};
 
 	use static_assertions::assert_impl_all;
 
-	use crate::backend::{Backend, JsonBackend, JsonError};
-
-	#[derive(Debug, Clone)]
-	pub struct Cleanup(PathBuf);
-
-	impl Cleanup {
-		pub fn new(test_name: &str, should_create: bool) -> IoResult<Self> {
-			let path = PathBuf::from(env!("CARGO_MANIFEST_DIR"))
-				.join("target")
-				.join("tests")
-				.join(test_name);
-
-			if should_create {
-				fs::create_dir_all(&path)?;
-			}
-
-			Ok(Self(path))
-		}
-	}
-
-	impl AsRef<Path> for Cleanup {
-		fn as_ref(&self) -> &Path {
-			self.0.as_ref()
-		}
-	}
-
-	impl AsRef<OsStr> for Cleanup {
-		fn as_ref(&self) -> &OsStr {
-			self.0.as_ref()
-		}
-	}
-
-	impl Drop for Cleanup {
-		#[allow(clippy::let_underscore_drop)]
-		fn drop(&mut self) {
-			let _ = fs::remove_dir_all(&self.0);
-		}
-	}
+	use crate::{
+		backend::{Backend, FsError, JsonBackend},
+		util::testing::FsCleanup as Cleanup,
+	};
 
 	assert_impl_all!(JsonBackend: Backend, Clone, Debug, Default, Send, Sync);
 
 	#[test]
-	fn new() -> Result<(), JsonError> {
-		let path = Cleanup::new("new", true)?;
-		let _blank = Cleanup::new("", true)?;
+	fn new() -> Result<(), FsError> {
+		let path = Cleanup::new("new", "json", true)?;
+		let _blank = Cleanup::new("", "json", true)?;
 		let backend = JsonBackend::new(&path)?;
 
-		assert_eq!(backend.base_directory, PathBuf::from(&path));
+		assert_eq!(backend.0, PathBuf::from(&path));
 
-		let file_path = Cleanup::new("file.txt", false)?;
+		let file_path = Cleanup::new("file.txt", "json", false)?;
 
 		fs::write(&file_path, "Hello, world!")?;
 
@@ -134,8 +86,8 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn init() -> Result<(), JsonError> {
-		let path = Cleanup::new("init", false)?;
+	async fn init() -> Result<(), FsError> {
+		let path = Cleanup::new("init", "json", false)?;
 		let backend = JsonBackend::new(&path)?;
 
 		backend.init().await?;
@@ -149,8 +101,8 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn has_and_create_table() -> Result<(), JsonError> {
-		let path = Cleanup::new("has_and_create_table", true)?;
+	async fn has_and_create_table() -> Result<(), FsError> {
+		let path = Cleanup::new("has_and_create_table", "json", true)?;
 		let backend = JsonBackend::new(&path)?;
 
 		backend.init().await?;
@@ -166,8 +118,8 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn get_keys() -> Result<(), JsonError> {
-		let path = Cleanup::new("get_keys", true)?;
+	async fn get_keys() -> Result<(), FsError> {
+		let path = Cleanup::new("get_keys", "json", true)?;
 		let backend = JsonBackend::new(&path)?;
 
 		backend.init().await?;
@@ -190,8 +142,8 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn create_and_delete_table() -> Result<(), JsonError> {
-		let path = Cleanup::new("create_and_delete_table", true)?;
+	async fn create_and_delete_table() -> Result<(), FsError> {
+		let path = Cleanup::new("create_and_delete_table", "json", true)?;
 		let backend = JsonBackend::new(&path)?;
 
 		backend.init().await?;
@@ -209,8 +161,8 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn get_and_create() -> Result<(), JsonError> {
-		let path = Cleanup::new("get_and_create", true)?;
+	async fn get_and_create() -> Result<(), FsError> {
+		let path = Cleanup::new("get_and_create", "json", true)?;
 		let backend = JsonBackend::new(&path)?;
 
 		backend.init().await?;
@@ -230,8 +182,8 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn update_and_replace() -> Result<(), JsonError> {
-		let path = Cleanup::new("update_and_replace", true)?;
+	async fn update_and_replace() -> Result<(), FsError> {
+		let path = Cleanup::new("update_and_replace", "json", true)?;
 		let backend = JsonBackend::new(&path)?;
 
 		backend.init().await?;
@@ -253,8 +205,8 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn delete() -> Result<(), JsonError> {
-		let path = Cleanup::new("delete", true)?;
+	async fn delete() -> Result<(), FsError> {
+		let path = Cleanup::new("delete", "json", true)?;
 		let backend = JsonBackend::new(&path)?;
 
 		backend.init().await?;
