@@ -1,6 +1,6 @@
-//! The backend that fetches and provides data for a [`Database`].
+//! The backend that fetches and provides data for the [`Starchart`].
 //!
-//! [`Database`]: crate::database::Database
+//! [`Starchart`]: crate::Starchart
 
 use std::{error::Error as StdError, iter::FromIterator};
 
@@ -13,31 +13,42 @@ use crate::{util::InnerUnwrap, Entry};
 
 pub mod future;
 
-#[cfg(feature = "cache")]
-mod cache;
+#[cfg(feature = "bincode")]
+mod bincode;
 #[cfg(feature = "fs")]
 #[cfg_attr(docsrs, doc(cfg(feature = "fs")))]
 pub mod fs;
 #[cfg(feature = "json")]
 mod json;
+#[cfg(feature = "memory")]
+mod memory;
+#[cfg(feature = "ron")]
+mod ron;
+#[cfg(feature = "toml")]
+mod toml;
+#[cfg(feature = "yaml")]
+mod yaml;
 
-#[cfg(feature = "cache")]
-pub use self::cache::CacheBackend;
-#[cfg(feature = "cache")]
-#[cfg_attr(feature = "cache", doc(hidden))]
-pub use self::cache::CacheError;
+#[cfg(feature = "bincode")]
+pub use self::bincode::BincodeBackend;
 #[cfg(feature = "fs")]
 #[cfg_attr(feature = "fs", doc(hidden))]
 pub use self::fs::FsError;
 #[cfg(feature = "json")]
 pub use self::json::JsonBackend;
-#[cfg(feature = "json")]
-#[cfg_attr(feature = "json", doc(hidden))]
-pub use self::json::JsonError;
+#[cfg(feature = "memory")]
+pub use self::memory::MemoryBackend;
+#[cfg(feature = "memory")]
+#[cfg_attr(feature = "memory", doc(hidden))]
+pub use self::memory::MemoryError;
+#[cfg(feature = "ron")]
+pub use self::ron::RonBackend;
+#[cfg(feature = "toml")]
+pub use self::toml::TomlBackend;
+#[cfg(feature = "yaml")]
+pub use self::yaml::YamlBackend;
 
-/// The backend to be used with a [`Database`].
-///
-/// [`Database`]: crate::Database
+/// The backend to be used to manage data.
 pub trait Backend: Send + Sync {
 	/// The [`Error`] type that the backend will report up.
 	///
@@ -57,36 +68,26 @@ pub trait Backend: Send + Sync {
 	///
 	/// # Safety
 	///
-	/// This should not fail, as it's ran upon dropping the [`Gateway`],
+	/// This should not fail, as it's ran upon dropping the [`Starchart`],
 	/// and panicking during a drop means resources haven't adequately been cleaned up,
 	/// which isn't inherintly UB however it should still be documented.
 	///
-	/// [`Gateway`]: crate::Gateway
+	/// [`Starchart`]: crate::Starchart
 	unsafe fn shutdown(&self) -> ShutdownFuture {
 		Box::pin(async {})
 	}
 
-	/// Check if a table exists in the [`Database`].
-	///
-	/// [`Database`]: crate::Database
+	/// Check if a table exists.
 	fn has_table<'a>(&'a self, table: &'a str) -> HasTableFuture<'a, Self::Error>;
 
-	/// Inserts or creates a table in the [`Database`].
-	///
-	/// [`Database`]: crate::Database
+	/// Inserts or creates a table.
 	fn create_table<'a>(&'a self, table: &'a str) -> CreateTableFuture<'a, Self::Error>;
 
-	/// Deletes or drops a table from the [`Database`].
-	///
-	/// [`Database`]: crate::Database
+	/// Deletes or drops a table.
 	fn delete_table<'a>(&'a self, table: &'a str) -> DeleteTableFuture<'a, Self::Error>;
 
-	/// Ensures a table exists in the [`Database`].
-	/// Uses [`has_table`] first, then [`create_table`] if it returns false.
-	///
-	/// [`Database`]: crate::Database
-	/// [`has_table`]: Self::has_table
-	/// [`create_table`]: Self::create_table
+	/// Ensures a table exists.
+	/// Uses [`Self::has_table`] first, then [`Self::create_table`] if it returns false.
 	fn ensure_table<'a>(&'a self, table: &'a str) -> EnsureTableFuture<'a, Self::Error> {
 		Box::pin(async move {
 			if !self.has_table(table).await? {
@@ -191,15 +192,15 @@ pub trait Backend: Send + Sync {
 }
 
 // need to cfg for cache because otherwise we would get errors if someone just ran `cargo test`
-#[cfg(all(test, feature = "cache"))]
+#[cfg(all(test, feature = "memory"))]
 mod tests {
 
-	use super::{Backend, CacheBackend, CacheError};
+	use super::{Backend, MemoryBackend, MemoryError};
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
 	async fn init() {
-		let backend = CacheBackend::new();
+		let backend = MemoryBackend::new();
 
 		assert!(Backend::init(&backend).await.is_ok());
 	}
@@ -208,7 +209,7 @@ mod tests {
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
 	async fn shutdown() {
-		let backend = CacheBackend::new();
+		let backend = MemoryBackend::new();
 
 		unsafe {
 			Backend::shutdown(&backend).await;
@@ -217,8 +218,8 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn ensure_table() -> Result<(), CacheError> {
-		let backend = CacheBackend::new();
+	async fn ensure_table() -> Result<(), MemoryError> {
+		let backend = MemoryBackend::new();
 
 		let table_name = "test";
 		assert!(!backend.has_table(table_name).await?);
@@ -232,8 +233,8 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn ensure() -> Result<(), CacheError> {
-		let backend = CacheBackend::new();
+	async fn ensure() -> Result<(), MemoryError> {
+		let backend = MemoryBackend::new();
 
 		let table_name = "test";
 		let id = "id";
@@ -252,8 +253,8 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn get_all() -> Result<(), CacheError> {
-		let backend = CacheBackend::new();
+	async fn get_all() -> Result<(), MemoryError> {
+		let backend = MemoryBackend::new();
 
 		backend.create_table("test").await?;
 
