@@ -2,21 +2,15 @@
 
 use thiserror::Error;
 
+#[doc(inline)]
+pub use crate::action::{ActionError, ActionRunError, ActionValidationError};
 use crate::backend::Backend;
-#[cfg(feature = "cache")]
-#[cfg_attr(docsrs, doc(cfg(feature = "cache")))]
-pub use crate::backend::CacheError;
 #[cfg(feature = "fs")]
 #[cfg_attr(docsrs, doc(cfg(feature = "fs")))]
 pub use crate::backend::FsError;
-#[cfg(feature = "json")]
-#[cfg_attr(docsrs, doc(cfg(feature = "json")))]
-pub use crate::backend::JsonError;
-#[doc(inline)]
-pub use crate::{
-	action::{ActionError, ActionRunError, ActionValidationError},
-	database::DatabaseError,
-};
+#[cfg(feature = "memory")]
+#[cfg_attr(docsrs, doc(cfg(feature = "memory")))]
+pub use crate::backend::MemoryError;
 
 // NOTE: This error shouldn't be used anywhere inside this crate, it's only meant for end users as an ease of use
 // error struct.
@@ -25,19 +19,16 @@ pub use crate::{
 /// An error enum to wrap around all possible errors within the crate.
 #[derive(Debug, Error)]
 pub enum ChartError<B: Backend> {
-	/// A [`CacheError`] has occurred.
-	#[cfg(feature = "cache")]
-	#[cfg_attr(docsrs, doc(cfg(feature = "cache")))]
+	/// A [`MemoryError`] has occurred.
+	#[cfg(feature = "memory")]
+	#[cfg_attr(docsrs, doc(cfg(feature = "memory")))]
 	#[error(transparent)]
-	Cache(#[from] CacheError),
+	Memory(#[from] MemoryError),
 	/// A [`FsError`] has occurred.
 	#[cfg(feature = "fs")]
 	#[cfg_attr(docsrs, doc(cfg(feature = "fs")))]
 	#[error(transparent)]
 	Fs(#[from] FsError),
-	/// A [`DatabaseError`] has occurred.
-	#[error(transparent)]
-	Database(#[from] DatabaseError<B::Error>),
 	/// An [`ActionValidationError`] has occurred.
 	#[error(transparent)]
 	ActionValidation(#[from] ActionValidationError),
